@@ -4,20 +4,19 @@ Main interface for sesv2 service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_sesv2.type_defs import BlacklistEntryTypeDef
+    from mypy_boto3_sesv2.type_defs import AccountDetailsTypeDef
 
-    data: BlacklistEntryTypeDef = {...}
+    data: AccountDetailsTypeDef = {...}
     ```
 """
 import sys
 from datetime import datetime
-from typing import Dict, List
+from typing import IO, Dict, List, Union
 
 if sys.version_info >= (3, 8):
     from typing import Literal
 else:
     from typing_extensions import Literal
-
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -25,31 +24,48 @@ else:
 
 
 __all__ = (
+    "AccountDetailsTypeDef",
     "BlacklistEntryTypeDef",
     "BodyTypeDef",
+    "BulkEmailEntryResultTypeDef",
     "CloudWatchDestinationTypeDef",
     "CloudWatchDimensionConfigurationTypeDef",
+    "ContactListDestinationTypeDef",
+    "ContactListTypeDef",
+    "ContactTypeDef",
     "ContentTypeDef",
+    "CustomVerificationEmailTemplateMetadataTypeDef",
     "DailyVolumeTypeDef",
     "DedicatedIpTypeDef",
     "DeliverabilityTestReportTypeDef",
     "DeliveryOptionsTypeDef",
+    "DestinationTypeDef",
     "DkimAttributesTypeDef",
     "DomainDeliverabilityCampaignTypeDef",
     "DomainDeliverabilityTrackingOptionTypeDef",
     "DomainIspPlacementTypeDef",
+    "EmailTemplateContentTypeDef",
+    "EmailTemplateMetadataTypeDef",
     "EventDestinationTypeDef",
+    "FailureInfoTypeDef",
     "IdentityInfoTypeDef",
+    "ImportDataSourceTypeDef",
+    "ImportDestinationTypeDef",
+    "ImportJobSummaryTypeDef",
     "InboxPlacementTrackingOptionTypeDef",
     "IspPlacementTypeDef",
     "KinesisFirehoseDestinationTypeDef",
     "MailFromAttributesTypeDef",
+    "MessageTagTypeDef",
     "MessageTypeDef",
     "OverallVolumeTypeDef",
     "PinpointDestinationTypeDef",
     "PlacementStatisticsTypeDef",
     "RawMessageTypeDef",
+    "ReplacementEmailContentTypeDef",
+    "ReplacementTemplateTypeDef",
     "ReputationOptionsTypeDef",
+    "ReviewDetailsTypeDef",
     "SendQuotaTypeDef",
     "SendingOptionsTypeDef",
     "SnsDestinationTypeDef",
@@ -57,14 +73,20 @@ __all__ = (
     "SuppressedDestinationSummaryTypeDef",
     "SuppressedDestinationTypeDef",
     "SuppressionAttributesTypeDef",
+    "SuppressionListDestinationTypeDef",
     "SuppressionOptionsTypeDef",
     "TagTypeDef",
     "TemplateTypeDef",
+    "TopicFilterTypeDef",
+    "TopicPreferenceTypeDef",
+    "TopicTypeDef",
     "TrackingOptionsTypeDef",
     "VolumeStatisticsTypeDef",
+    "BulkEmailContentTypeDef",
+    "BulkEmailEntryTypeDef",
     "CreateDeliverabilityTestReportResponseTypeDef",
     "CreateEmailIdentityResponseTypeDef",
-    "DestinationTypeDef",
+    "CreateImportJobResponseTypeDef",
     "DkimSigningAttributesTypeDef",
     "EmailContentTypeDef",
     "EventDestinationDefinitionTypeDef",
@@ -72,24 +94,52 @@ __all__ = (
     "GetBlacklistReportsResponseTypeDef",
     "GetConfigurationSetEventDestinationsResponseTypeDef",
     "GetConfigurationSetResponseTypeDef",
+    "GetContactListResponseTypeDef",
+    "GetContactResponseTypeDef",
+    "GetCustomVerificationEmailTemplateResponseTypeDef",
     "GetDedicatedIpResponseTypeDef",
     "GetDedicatedIpsResponseTypeDef",
     "GetDeliverabilityDashboardOptionsResponseTypeDef",
     "GetDeliverabilityTestReportResponseTypeDef",
     "GetDomainDeliverabilityCampaignResponseTypeDef",
     "GetDomainStatisticsReportResponseTypeDef",
+    "GetEmailIdentityPoliciesResponseTypeDef",
     "GetEmailIdentityResponseTypeDef",
+    "GetEmailTemplateResponseTypeDef",
+    "GetImportJobResponseTypeDef",
     "GetSuppressedDestinationResponseTypeDef",
     "ListConfigurationSetsResponseTypeDef",
+    "ListContactListsResponseTypeDef",
+    "ListContactsFilterTypeDef",
+    "ListContactsResponseTypeDef",
+    "ListCustomVerificationEmailTemplatesResponseTypeDef",
     "ListDedicatedIpPoolsResponseTypeDef",
     "ListDeliverabilityTestReportsResponseTypeDef",
     "ListDomainDeliverabilityCampaignsResponseTypeDef",
     "ListEmailIdentitiesResponseTypeDef",
+    "ListEmailTemplatesResponseTypeDef",
+    "ListImportJobsResponseTypeDef",
+    "ListManagementOptionsTypeDef",
     "ListSuppressedDestinationsResponseTypeDef",
     "ListTagsForResourceResponseTypeDef",
-    "MessageTagTypeDef",
     "PutEmailIdentityDkimSigningAttributesResponseTypeDef",
+    "SendBulkEmailResponseTypeDef",
+    "SendCustomVerificationEmailResponseTypeDef",
     "SendEmailResponseTypeDef",
+    "TestRenderEmailTemplateResponseTypeDef",
+)
+
+AccountDetailsTypeDef = TypedDict(
+    "AccountDetailsTypeDef",
+    {
+        "MailType": Literal["MARKETING", "TRANSACTIONAL"],
+        "WebsiteURL": str,
+        "ContactLanguage": Literal["EN", "JA"],
+        "UseCaseDescription": str,
+        "AdditionalContactEmailAddresses": List[str],
+        "ReviewDetails": "ReviewDetailsTypeDef",
+    },
+    total=False,
 )
 
 BlacklistEntryTypeDef = TypedDict(
@@ -102,6 +152,31 @@ BodyTypeDef = TypedDict(
     "BodyTypeDef", {"Text": "ContentTypeDef", "Html": "ContentTypeDef"}, total=False
 )
 
+BulkEmailEntryResultTypeDef = TypedDict(
+    "BulkEmailEntryResultTypeDef",
+    {
+        "Status": Literal[
+            "SUCCESS",
+            "MESSAGE_REJECTED",
+            "MAIL_FROM_DOMAIN_NOT_VERIFIED",
+            "CONFIGURATION_SET_NOT_FOUND",
+            "TEMPLATE_NOT_FOUND",
+            "ACCOUNT_SUSPENDED",
+            "ACCOUNT_THROTTLED",
+            "ACCOUNT_DAILY_QUOTA_EXCEEDED",
+            "INVALID_SENDING_POOL_NAME",
+            "ACCOUNT_SENDING_PAUSED",
+            "CONFIGURATION_SET_SENDING_PAUSED",
+            "INVALID_PARAMETER",
+            "TRANSIENT_FAILURE",
+            "FAILED",
+        ],
+        "Error": str,
+        "MessageId": str,
+    },
+    total=False,
+)
+
 CloudWatchDestinationTypeDef = TypedDict(
     "CloudWatchDestinationTypeDef",
     {"DimensionConfigurations": List["CloudWatchDimensionConfigurationTypeDef"]},
@@ -116,6 +191,27 @@ CloudWatchDimensionConfigurationTypeDef = TypedDict(
     },
 )
 
+ContactListDestinationTypeDef = TypedDict(
+    "ContactListDestinationTypeDef",
+    {"ContactListName": str, "ContactListImportAction": Literal["DELETE", "PUT"]},
+)
+
+ContactListTypeDef = TypedDict(
+    "ContactListTypeDef", {"ContactListName": str, "LastUpdatedTimestamp": datetime}, total=False
+)
+
+ContactTypeDef = TypedDict(
+    "ContactTypeDef",
+    {
+        "EmailAddress": str,
+        "TopicPreferences": List["TopicPreferenceTypeDef"],
+        "TopicDefaultPreferences": List["TopicPreferenceTypeDef"],
+        "UnsubscribeAll": bool,
+        "LastUpdatedTimestamp": datetime,
+    },
+    total=False,
+)
+
 _RequiredContentTypeDef = TypedDict("_RequiredContentTypeDef", {"Data": str})
 _OptionalContentTypeDef = TypedDict("_OptionalContentTypeDef", {"Charset": str}, total=False)
 
@@ -124,6 +220,18 @@ class ContentTypeDef(_RequiredContentTypeDef, _OptionalContentTypeDef):
     pass
 
 
+CustomVerificationEmailTemplateMetadataTypeDef = TypedDict(
+    "CustomVerificationEmailTemplateMetadataTypeDef",
+    {
+        "TemplateName": str,
+        "FromEmailAddress": str,
+        "TemplateSubject": str,
+        "SuccessRedirectionURL": str,
+        "FailureRedirectionURL": str,
+    },
+    total=False,
+)
+
 DailyVolumeTypeDef = TypedDict(
     "DailyVolumeTypeDef",
     {
@@ -166,6 +274,12 @@ DeliveryOptionsTypeDef = TypedDict(
     total=False,
 )
 
+DestinationTypeDef = TypedDict(
+    "DestinationTypeDef",
+    {"ToAddresses": List[str], "CcAddresses": List[str], "BccAddresses": List[str]},
+    total=False,
+)
+
 DkimAttributesTypeDef = TypedDict(
     "DkimAttributesTypeDef",
     {
@@ -220,6 +334,14 @@ DomainIspPlacementTypeDef = TypedDict(
     total=False,
 )
 
+EmailTemplateContentTypeDef = TypedDict(
+    "EmailTemplateContentTypeDef", {"Subject": str, "Text": str, "Html": str}, total=False
+)
+
+EmailTemplateMetadataTypeDef = TypedDict(
+    "EmailTemplateMetadataTypeDef", {"TemplateName": str, "CreatedTimestamp": datetime}, total=False
+)
+
 _RequiredEventDestinationTypeDef = TypedDict(
     "_RequiredEventDestinationTypeDef",
     {
@@ -235,6 +357,7 @@ _RequiredEventDestinationTypeDef = TypedDict(
                 "CLICK",
                 "RENDERING_FAILURE",
                 "DELIVERY_DELAY",
+                "SUBSCRIPTION",
             ]
         ],
     },
@@ -256,6 +379,10 @@ class EventDestinationTypeDef(_RequiredEventDestinationTypeDef, _OptionalEventDe
     pass
 
 
+FailureInfoTypeDef = TypedDict(
+    "FailureInfoTypeDef", {"FailedRecordsS3Url": str, "ErrorMessage": str}, total=False
+)
+
 IdentityInfoTypeDef = TypedDict(
     "IdentityInfoTypeDef",
     {
@@ -266,6 +393,30 @@ IdentityInfoTypeDef = TypedDict(
     total=False,
 )
 
+ImportDataSourceTypeDef = TypedDict(
+    "ImportDataSourceTypeDef", {"S3Url": str, "DataFormat": Literal["CSV", "JSON"]}
+)
+
+ImportDestinationTypeDef = TypedDict(
+    "ImportDestinationTypeDef",
+    {
+        "SuppressionListDestination": "SuppressionListDestinationTypeDef",
+        "ContactListDestination": "ContactListDestinationTypeDef",
+    },
+    total=False,
+)
+
+ImportJobSummaryTypeDef = TypedDict(
+    "ImportJobSummaryTypeDef",
+    {
+        "JobId": str,
+        "ImportDestination": "ImportDestinationTypeDef",
+        "JobStatus": Literal["CREATED", "PROCESSING", "COMPLETED", "FAILED"],
+        "CreatedTimestamp": datetime,
+    },
+    total=False,
+)
+
 InboxPlacementTrackingOptionTypeDef = TypedDict(
     "InboxPlacementTrackingOptionTypeDef", {"Global": bool, "TrackedIsps": List[str]}, total=False
 )
@@ -289,6 +440,8 @@ MailFromAttributesTypeDef = TypedDict(
     },
 )
 
+MessageTagTypeDef = TypedDict("MessageTagTypeDef", {"Name": str, "Value": str})
+
 MessageTypeDef = TypedDict("MessageTypeDef", {"Subject": "ContentTypeDef", "Body": "BodyTypeDef"})
 
 OverallVolumeTypeDef = TypedDict(
@@ -317,7 +470,17 @@ PlacementStatisticsTypeDef = TypedDict(
     total=False,
 )
 
-RawMessageTypeDef = TypedDict("RawMessageTypeDef", {"Data": bytes})
+RawMessageTypeDef = TypedDict("RawMessageTypeDef", {"Data": Union[bytes, IO[bytes]]})
+
+ReplacementEmailContentTypeDef = TypedDict(
+    "ReplacementEmailContentTypeDef",
+    {"ReplacementTemplate": "ReplacementTemplateTypeDef"},
+    total=False,
+)
+
+ReplacementTemplateTypeDef = TypedDict(
+    "ReplacementTemplateTypeDef", {"ReplacementTemplateData": str}, total=False
+)
 
 ReputationOptionsTypeDef = TypedDict(
     "ReputationOptionsTypeDef",
@@ -325,6 +488,12 @@ ReputationOptionsTypeDef = TypedDict(
     total=False,
 )
 
+ReviewDetailsTypeDef = TypedDict(
+    "ReviewDetailsTypeDef",
+    {"Status": Literal["PENDING", "FAILED", "GRANTED", "DENIED"], "CaseId": str},
+    total=False,
+)
+
 SendQuotaTypeDef = TypedDict(
     "SendQuotaTypeDef",
     {"Max24HourSend": float, "MaxSendRate": float, "SentLast24Hours": float},
@@ -367,6 +536,10 @@ SuppressionAttributesTypeDef = TypedDict(
     total=False,
 )
 
+SuppressionListDestinationTypeDef = TypedDict(
+    "SuppressionListDestinationTypeDef", {"SuppressionListImportAction": Literal["DELETE", "PUT"]}
+)
+
 SuppressionOptionsTypeDef = TypedDict(
     "SuppressionOptionsTypeDef",
     {"SuppressedReasons": List[Literal["BOUNCE", "COMPLAINT"]]},
@@ -376,9 +549,32 @@ SuppressionOptionsTypeDef = TypedDict(
 TagTypeDef = TypedDict("TagTypeDef", {"Key": str, "Value": str})
 
 TemplateTypeDef = TypedDict(
-    "TemplateTypeDef", {"TemplateArn": str, "TemplateData": str}, total=False
+    "TemplateTypeDef", {"TemplateName": str, "TemplateArn": str, "TemplateData": str}, total=False
 )
 
+TopicFilterTypeDef = TypedDict(
+    "TopicFilterTypeDef", {"TopicName": str, "UseDefaultIfPreferenceUnavailable": bool}, total=False
+)
+
+TopicPreferenceTypeDef = TypedDict(
+    "TopicPreferenceTypeDef", {"TopicName": str, "SubscriptionStatus": Literal["OPT_IN", "OPT_OUT"]}
+)
+
+_RequiredTopicTypeDef = TypedDict(
+    "_RequiredTopicTypeDef",
+    {
+        "TopicName": str,
+        "DisplayName": str,
+        "DefaultSubscriptionStatus": Literal["OPT_IN", "OPT_OUT"],
+    },
+)
+_OptionalTopicTypeDef = TypedDict("_OptionalTopicTypeDef", {"Description": str}, total=False)
+
+
+class TopicTypeDef(_RequiredTopicTypeDef, _OptionalTopicTypeDef):
+    pass
+
+
 TrackingOptionsTypeDef = TypedDict("TrackingOptionsTypeDef", {"CustomRedirectDomain": str})
 
 VolumeStatisticsTypeDef = TypedDict(
@@ -387,6 +583,27 @@ VolumeStatisticsTypeDef = TypedDict(
     total=False,
 )
 
+BulkEmailContentTypeDef = TypedDict(
+    "BulkEmailContentTypeDef", {"Template": "TemplateTypeDef"}, total=False
+)
+
+_RequiredBulkEmailEntryTypeDef = TypedDict(
+    "_RequiredBulkEmailEntryTypeDef", {"Destination": "DestinationTypeDef"}
+)
+_OptionalBulkEmailEntryTypeDef = TypedDict(
+    "_OptionalBulkEmailEntryTypeDef",
+    {
+        "ReplacementTags": List["MessageTagTypeDef"],
+        "ReplacementEmailContent": "ReplacementEmailContentTypeDef",
+    },
+    total=False,
+)
+
+
+class BulkEmailEntryTypeDef(_RequiredBulkEmailEntryTypeDef, _OptionalBulkEmailEntryTypeDef):
+    pass
+
+
 CreateDeliverabilityTestReportResponseTypeDef = TypedDict(
     "CreateDeliverabilityTestReportResponseTypeDef",
     {"ReportId": str, "DeliverabilityTestStatus": Literal["IN_PROGRESS", "COMPLETED"]},
@@ -402,10 +619,8 @@ CreateEmailIdentityResponseTypeDef = TypedDict(
     total=False,
 )
 
-DestinationTypeDef = TypedDict(
-    "DestinationTypeDef",
-    {"ToAddresses": List[str], "CcAddresses": List[str], "BccAddresses": List[str]},
-    total=False,
+CreateImportJobResponseTypeDef = TypedDict(
+    "CreateImportJobResponseTypeDef", {"JobId": str}, total=False
 )
 
 DkimSigningAttributesTypeDef = TypedDict(
@@ -433,6 +648,7 @@ EventDestinationDefinitionTypeDef = TypedDict(
                 "CLICK",
                 "RENDERING_FAILURE",
                 "DELIVERY_DELAY",
+                "SUBSCRIPTION",
             ]
         ],
         "KinesisFirehoseDestination": "KinesisFirehoseDestinationTypeDef",
@@ -452,6 +668,7 @@ GetAccountResponseTypeDef = TypedDict(
         "SendQuota": "SendQuotaTypeDef",
         "SendingEnabled": bool,
         "SuppressionAttributes": "SuppressionAttributesTypeDef",
+        "Details": "AccountDetailsTypeDef",
     },
     total=False,
 )
@@ -481,6 +698,47 @@ GetConfigurationSetResponseTypeDef = TypedDict(
     total=False,
 )
 
+GetContactListResponseTypeDef = TypedDict(
+    "GetContactListResponseTypeDef",
+    {
+        "ContactListName": str,
+        "Topics": List["TopicTypeDef"],
+        "Description": str,
+        "CreatedTimestamp": datetime,
+        "LastUpdatedTimestamp": datetime,
+        "Tags": List["TagTypeDef"],
+    },
+    total=False,
+)
+
+GetContactResponseTypeDef = TypedDict(
+    "GetContactResponseTypeDef",
+    {
+        "ContactListName": str,
+        "EmailAddress": str,
+        "TopicPreferences": List["TopicPreferenceTypeDef"],
+        "TopicDefaultPreferences": List["TopicPreferenceTypeDef"],
+        "UnsubscribeAll": bool,
+        "AttributesData": str,
+        "CreatedTimestamp": datetime,
+        "LastUpdatedTimestamp": datetime,
+    },
+    total=False,
+)
+
+GetCustomVerificationEmailTemplateResponseTypeDef = TypedDict(
+    "GetCustomVerificationEmailTemplateResponseTypeDef",
+    {
+        "TemplateName": str,
+        "FromEmailAddress": str,
+        "TemplateSubject": str,
+        "TemplateContent": str,
+        "SuccessRedirectionURL": str,
+        "FailureRedirectionURL": str,
+    },
+    total=False,
+)
+
 GetDedicatedIpResponseTypeDef = TypedDict(
     "GetDedicatedIpResponseTypeDef", {"DedicatedIp": "DedicatedIpTypeDef"}, total=False
 )
@@ -545,6 +803,10 @@ GetDomainStatisticsReportResponseTypeDef = TypedDict(
     {"OverallVolume": "OverallVolumeTypeDef", "DailyVolumes": List["DailyVolumeTypeDef"]},
 )
 
+GetEmailIdentityPoliciesResponseTypeDef = TypedDict(
+    "GetEmailIdentityPoliciesResponseTypeDef", {"Policies": Dict[str, str]}, total=False
+)
+
 GetEmailIdentityResponseTypeDef = TypedDict(
     "GetEmailIdentityResponseTypeDef",
     {
@@ -553,7 +815,30 @@ GetEmailIdentityResponseTypeDef = TypedDict(
         "VerifiedForSendingStatus": bool,
         "DkimAttributes": "DkimAttributesTypeDef",
         "MailFromAttributes": "MailFromAttributesTypeDef",
+        "Policies": Dict[str, str],
         "Tags": List["TagTypeDef"],
+        "ConfigurationSetName": str,
+    },
+    total=False,
+)
+
+GetEmailTemplateResponseTypeDef = TypedDict(
+    "GetEmailTemplateResponseTypeDef",
+    {"TemplateName": str, "TemplateContent": "EmailTemplateContentTypeDef"},
+)
+
+GetImportJobResponseTypeDef = TypedDict(
+    "GetImportJobResponseTypeDef",
+    {
+        "JobId": str,
+        "ImportDestination": "ImportDestinationTypeDef",
+        "ImportDataSource": "ImportDataSourceTypeDef",
+        "FailureInfo": "FailureInfoTypeDef",
+        "JobStatus": Literal["CREATED", "PROCESSING", "COMPLETED", "FAILED"],
+        "CreatedTimestamp": datetime,
+        "CompletedTimestamp": datetime,
+        "ProcessedRecordsCount": int,
+        "FailedRecordsCount": int,
     },
     total=False,
 )
@@ -569,6 +854,33 @@ ListConfigurationSetsResponseTypeDef = TypedDict(
     total=False,
 )
 
+ListContactListsResponseTypeDef = TypedDict(
+    "ListContactListsResponseTypeDef",
+    {"ContactLists": List["ContactListTypeDef"], "NextToken": str},
+    total=False,
+)
+
+ListContactsFilterTypeDef = TypedDict(
+    "ListContactsFilterTypeDef",
+    {"FilteredStatus": Literal["OPT_IN", "OPT_OUT"], "TopicFilter": "TopicFilterTypeDef"},
+    total=False,
+)
+
+ListContactsResponseTypeDef = TypedDict(
+    "ListContactsResponseTypeDef",
+    {"Contacts": List["ContactTypeDef"], "NextToken": str},
+    total=False,
+)
+
+ListCustomVerificationEmailTemplatesResponseTypeDef = TypedDict(
+    "ListCustomVerificationEmailTemplatesResponseTypeDef",
+    {
+        "CustomVerificationEmailTemplates": List["CustomVerificationEmailTemplateMetadataTypeDef"],
+        "NextToken": str,
+    },
+    total=False,
+)
+
 ListDedicatedIpPoolsResponseTypeDef = TypedDict(
     "ListDedicatedIpPoolsResponseTypeDef",
     {"DedicatedIpPools": List[str], "NextToken": str},
@@ -613,6 +925,32 @@ ListEmailIdentitiesResponseTypeDef = TypedDict(
     total=False,
 )
 
+ListEmailTemplatesResponseTypeDef = TypedDict(
+    "ListEmailTemplatesResponseTypeDef",
+    {"TemplatesMetadata": List["EmailTemplateMetadataTypeDef"], "NextToken": str},
+    total=False,
+)
+
+ListImportJobsResponseTypeDef = TypedDict(
+    "ListImportJobsResponseTypeDef",
+    {"ImportJobs": List["ImportJobSummaryTypeDef"], "NextToken": str},
+    total=False,
+)
+
+_RequiredListManagementOptionsTypeDef = TypedDict(
+    "_RequiredListManagementOptionsTypeDef", {"ContactListName": str}
+)
+_OptionalListManagementOptionsTypeDef = TypedDict(
+    "_OptionalListManagementOptionsTypeDef", {"TopicName": str}, total=False
+)
+
+
+class ListManagementOptionsTypeDef(
+    _RequiredListManagementOptionsTypeDef, _OptionalListManagementOptionsTypeDef
+):
+    pass
+
+
 ListSuppressedDestinationsResponseTypeDef = TypedDict(
     "ListSuppressedDestinationsResponseTypeDef",
     {
@@ -626,8 +964,6 @@ ListTagsForResourceResponseTypeDef = TypedDict(
     "ListTagsForResourceResponseTypeDef", {"Tags": List["TagTypeDef"]}
 )
 
-MessageTagTypeDef = TypedDict("MessageTagTypeDef", {"Name": str, "Value": str})
-
 PutEmailIdentityDkimSigningAttributesResponseTypeDef = TypedDict(
     "PutEmailIdentityDkimSigningAttributesResponseTypeDef",
     {
@@ -637,4 +973,16 @@ PutEmailIdentityDkimSigningAttributesResponseTypeDef = TypedDict(
     total=False,
 )
 
+SendBulkEmailResponseTypeDef = TypedDict(
+    "SendBulkEmailResponseTypeDef", {"BulkEmailEntryResults": List["BulkEmailEntryResultTypeDef"]}
+)
+
+SendCustomVerificationEmailResponseTypeDef = TypedDict(
+    "SendCustomVerificationEmailResponseTypeDef", {"MessageId": str}, total=False
+)
+
 SendEmailResponseTypeDef = TypedDict("SendEmailResponseTypeDef", {"MessageId": str}, total=False)
+
+TestRenderEmailTemplateResponseTypeDef = TypedDict(
+    "TestRenderEmailTemplateResponseTypeDef", {"RenderedTemplate": str}
+)
